@@ -26,6 +26,9 @@ pub use alloc::vec;
 pub use alloc::boxed;
 #[cfg(target_arch="avr")]
 pub use alloc::rc;
+#[cfg(target_arch="avr")]
+pub use alloc::string;
+
 
 #[cfg(not(target_arch="avr"))]
 pub use std::boxed;
@@ -89,7 +92,6 @@ pub fn initialise() {
  * Implementation of the Rust GlobalAlloc trait for our First-Fit allocator,
  * allowing it to be used as the Rust global allocator.
  */
-#[optimize(speed)]
 unsafe impl<const H:usize, const S:usize, const S2:usize> GlobalAlloc for GlobalAllocator<H,S,S2> {
   unsafe fn alloc(&self, layout: Layout) -> *mut u8 {
     let heap = crate::panic_if_none!(self.heap.get().as_mut());
