@@ -5,7 +5,28 @@
  */
 //! A helper module that maps standard ATmega pins into equivalent Arduino
 //! names.
-
+//!
+//! # Usage
+//! You can create an instance of the `Arduino` type From the generic
+//! hardware instance provided by the `avr_oxide::hal::<<device>>::hardware`
+//! crate.  This then allows you to refer to pins etc. using the Arduino
+//! naming conventions instead of the AVR device's own naming conventions.
+//!
+//! ```rust
+//! use avr_oxide::hal::atmega4809;
+//! use avr_oxide::arduino;
+//! use avr_oxide::hal::generic::port::{ Pin, PinMode };
+//!
+//! fn use_arduino_types() {
+//!   let hardware = atmega4809::hardware::instance();
+//!   let arduino  = arduino::nanoevery::Arduino::from(hardware);
+//!
+//!   // We can now refer to Pord D, pin 3 on an Arduino Nano Every as
+//!   // `arduino.a0`
+//!   arduino.a0.set_mode(PinMode::Output);
+//!   arduino.a0.set_high();
+//! }
+//! ```
 
 // Imports ===================================================================
 
@@ -92,6 +113,9 @@ pub mod nanoevery {
 
     pub watchdog: &'static mut atmega4809::watchdog::WatchdogImpl,
 
+    pub eeprom: &'static mut atmega4809::eeprom::eeprom::EepromImpl,
+    pub userrow: &'static mut atmega4809::eeprom::userrow::EepromImpl,
+
     #[cfg(feature="usart3")]
     pub usb_serial: &'static mut atmega4809::serial::usart3::SerialImpl,
     #[cfg(feature="usart3")]
@@ -140,6 +164,9 @@ pub mod nanoevery {
 
         watchdog: avr.watchdog,
 
+        eeprom: avr.eeprom,
+        userrow: avr.userrow,
+
         #[cfg(feature="usart3")]
         usb_serial: avr.usart3.mux(atmega4809::serial::usart3::SerialPortPins::PortB54),
         #[cfg(feature="usart3")]
