@@ -17,7 +17,7 @@ use crate::alloc;
 
 // Declarations ==============================================================
 extern {
-  fn __oxide_main() -> u8;
+  fn __oxide_main() -> !;
 }
 
 // Code ======================================================================
@@ -35,9 +35,13 @@ fn _oxide_boot() {
     #[cfg(feature="atmega4809")]
     crate::hal::atmega4809::cpu::clock().clk_per_prescaler(clock::MASTER_CLOCK_PRESCALER);
 
+    // Create the supervisor
+    let mut supervisor = crate::oxide::create_supervisor();
+    crate::oxide::set_global_supervisor(&mut supervisor);
+
     // Spawn the main thread
     let _jh = thread::spawn_threadunsafe(||{
-      __oxide_main()
+      __oxide_main();
     });
 
     // Enter the scheduler loop
