@@ -4,7 +4,44 @@
  * Copyright (c) All Rights Reserved, Tim Walls
  */
 //! Abstractions for serial I/O devices, implementing the Read/Write interfaces
-//! provided by std::io
+//! provided by [`avr_oxide::io`].
+//!
+//! The SerialPort implementation supports the port mnultiplexing of the AVR
+//! controller, meaning that an underlying USART may be connected to different
+//! pins of the controller at runtime.  Thus the device must be instantiated
+//! with both the USART device to use, and the pins which will be used for
+//! receive and transmit.
+//!
+//! # Usage
+//! ```no_run
+//! # #![no_std]
+//! # #![no_main]
+//! #
+//! # use avr_oxide::hal::atmega4809::hardware;
+//! # use avr_oxide::alloc::boxed::Box;
+//! # use avr_oxide::devices::UsesPin;
+//! # use avr_oxide::devices::debouncer::Debouncer;
+//! # use avr_oxide::devices::{ Handle, OxideLed, OxideButton, OxideSerialPort };
+//! # use avr_oxide::hal::generic::serial::{BaudRate, DataBits, Parity, SerialPortMode, StopBits};
+//! # use avr_oxide::io::Write;
+//! # use avr_oxide::arduino;
+//! #
+//! # #[avr_oxide::main(chip="atmega4809")]
+//! # pub fn main() {
+//! #   let supervisor = avr_oxide::oxide::instance();
+//! #   let hardware = hardware::instance();
+//!   let arduino = arduino::nanoevery::Arduino::from(hardware);
+//!
+//!   // Configure the serial port early so we can get any panic!() messages
+//!   let mut serial= OxideSerialPort::using_port_and_pins(arduino.usb_serial,
+//!                                                        arduino.usb_serial_tx,
+//!                                                        arduino.usb_serial_rx).mode(SerialPortMode::Asynch(BaudRate::Baud9600, DataBits::Bits8, Parity::None, StopBits::Bits1));
+//!   serial.write(b"Welcome to AVRoxide\n");
+//!
+//! #    supervisor.run();
+//! # }
+//! ```
+
 
 // Imports ===================================================================
 use crate::hal::generic::serial::{SerialRxTx, ReadHandlerResult, SerialError, SerialPortMode, SerialPortIdentity, SerialWriteEventCallback, SerialReadEventCallback, SerialErrorEventCallback};
@@ -12,10 +49,15 @@ use crate::event::{EventSink, EventSource, OxideEvent, OxideEventEnvelope};
 use core::marker::PhantomData;
 use core::cell::RefCell;
 use core::ops::DerefMut;
+use ufmt::derive::uDebug;
+use avr_oxide::devices::internal::StaticShareable;
+use oxide_macros::Persist;
 use crate::alloc::boxed::Box;
+use crate::devices::Handle;
 use crate::hal::generic::callback::IsrCallback;
 use crate::hal::generic::port::{Pin, PinMode};
 use crate::panic_if_none;
+use crate::util::{BitField, BitIndex};
 
 // Declarations ===============================================================
 pub trait SerialCallback = FnMut(SerialPortIdentity, SerialState) -> ();
@@ -23,7 +65,7 @@ pub trait SerialCallback = FnMut(SerialPortIdentity, SerialState) -> ();
 /**
  * State of the serial port sent with Oxide events.
  */
-#[derive(PartialEq,Eq,Clone,Copy)]
+#[derive(PartialEq,Eq,Clone,Copy,uDebug,Persist)]
 pub enum SerialState {
   /// There is data waiting in the buffer for someone to read it
   ReadAvailable,
@@ -42,8 +84,7 @@ pub enum SerialState {
 /**
  * Options for controlling how data is transmitted by the serial port device.
  */
-#[derive(Copy,Clone)]
-pub struct TransmitOptions(u8);
+pub type SerialOptions = BitField<1>;
 
 
 /**
@@ -62,66 +103,100 @@ where
   rx: &'static R,
   phantom: PhantomData<S>,
 
-  tx_options: TransmitOptions,
+  serial_options: SerialOptions,
 
   on_event: RefCell<Option<Box<dyn SerialCallback + 'sp>>>
 }
 
-// Code ======================================================================
+impl<'sp,P,T,R,S> StaticShareable for SerialPort<'sp,P,T,R,S>
+where
+  P: 'static + SerialRxTx,
+  T: 'static + Pin,
+  R: 'static + Pin,
+  S: EventSink
+{}
 
-impl TransmitOptions {
+
+// Code ======================================================================
+const TX_FLUSH_ON_EOL: BitIndex =  BitIndex::bit(0);
+const TX_CR_TO_CRLF:   BitIndex =  BitIndex::bit(1);
+const TX_LF_TO_CRLF:   BitIndex =  BitIndex::bit(2);
+const INTERACTIVE:     BitIndex =  BitIndex::bit(3);
+
+/**
+ * Configuration of various translation/usability options for the serial
+ * port device.
+ *
+ * | Option         | Effect                                       |
+ * | -------------- | -------------------------------------------- |
+ * | `flush_on_eol` | Automatically flush when an end-of-line is transmitted |
+ * | `cr_to_crlf`   | Translate sent CRs to CRLF |
+ * | `lf_to_crlf`   | Translate sent LFs to CRLF |
+ * | `interactive`  | This is an interactive terminal, reading from the device will automatically flush the transmit buffer first |
+ */
+impl SerialOptions {
   /// Indicate that the device should automatically flush when an end-of-line
   /// (CR or LF) character is sent
   /// is sent.
   pub fn set_flush_on_eol(&mut self, flag: bool) {
-    self.0 = match flag {
-      true  => self.0 & 0b11111110,
-      false => self.0 | 0b00000001
-    }
+    self.set_or_clr(TX_FLUSH_ON_EOL, flag);
   }
 
   /// True iff the device should automatically flush when an LF character
   /// is sent.
   pub fn flush_on_eol(self) -> bool {
-    self.0 & 0b00000001 > 0
+    self.is_set(TX_FLUSH_ON_EOL)
   }
 
   /// Indicate that CR should be translated to CRLF automatically
   pub fn set_cr_to_crlf(&mut self, flag: bool) {
-    self.0 = match flag {
-      true  => self.0 & 0b11111101,
-      false => self.0 | 0b00000010
-    }
+    self.set_or_clr(TX_CR_TO_CRLF, flag);
   }
 
   /// True iff the device should automatically translate CR to CRLF.
   pub fn cr_to_crlf(&self) -> bool {
-    self.0 & 0b00000010 > 0
+    self.is_set(TX_CR_TO_CRLF)
   }
 
   /// Indicate that LF should be translated to CRLF automatically
   pub fn set_lf_to_crlf(&mut self, flag: bool) {
-    self.0 = match flag {
-      true  => self.0 & 0b11111011,
-      false => self.0 | 0b00000100
-    }
+    self.set_or_clr(TX_LF_TO_CRLF, flag);
   }
 
   /// True iff the device should automatically translate LF to CRLF.
   pub fn lf_to_crlf(&self) -> bool {
-    self.0 & 0b00000100 > 0
+    self.is_set(TX_LF_TO_CRLF)
+  }
+  /// Indicate that this is an interactive terminal.  Effects:
+  ///   * A call to read() will automatically flush the transmit buffer
+  pub fn set_interactive(&mut self, flag: bool) {
+    self.set_or_clr(INTERACTIVE, flag);
+  }
+
+  /// True iff this is an interative terminal
+  pub fn interactive(&self) -> bool {
+    self.is_set(INTERACTIVE)
+  }
+
+  /// Clear all settings that result in the data being translated in any
+  /// way (e.g. CR to CRLF type translations.)  Use this to ensure a serial
+  /// port is 'clean' for sending/receiving binary data.
+  pub fn disable_translations(&mut self) {
+    self.set_cr_to_crlf(false);
+    self.set_lf_to_crlf(false);
   }
 }
 
-impl Default for TransmitOptions {
+impl Default for SerialOptions {
   /**
    * Default transmit options:
    *  * DO flush automatically on End-of-Line
    *  * DO NOT translate CR to CRLF
    *  * DO NOT translate LF to CRLF
+   *  * Interactive mode NOT enabled
    */
   fn default() -> Self {
-    TransmitOptions(0b00000001)
+    BitField::with_bits_set(&[TX_FLUSH_ON_EOL])
   }
 }
 
@@ -149,7 +224,7 @@ where
       port, tx, rx,
       phantom: PhantomData::default(),
 
-      tx_options: TransmitOptions::default(),
+      serial_options: SerialOptions::default(),
 
       on_event: RefCell::new(None)
     }
@@ -175,15 +250,22 @@ where
   /**
    * Get the currently configured transmission options.
    */
-  pub fn get_transmit_options(&self) -> TransmitOptions {
-    self.tx_options
+  pub fn get_serial_options(&self) -> SerialOptions {
+    self.serial_options
   }
 
   /**
    * Set the transmission options.
    */
-  pub fn set_transmit_options(&mut self, options: TransmitOptions) {
-    self.tx_options = options;
+  pub fn set_serial_options(&mut self, options: SerialOptions) {
+    self.serial_options = options;
+  }
+
+  /**
+   * Mutably access the serial options
+   */
+  pub fn serial_options(&mut self) -> &mut SerialOptions {
+    &mut self.serial_options
   }
 }
 
@@ -233,8 +315,26 @@ where
   R: 'static + Pin,
   S: EventSink
 {
-  fn read(&mut self, _buf: &mut [u8]) -> crate::io::Result<usize> {
-    todo!()
+  fn read(&mut self, buf: &mut [u8]) -> crate::io::Result<usize> {
+    let mut cnt = 0usize;
+
+    if self.serial_options.interactive() {
+      self.port.flush();
+    }
+
+    while cnt < buf.len() {
+      match self.port.try_read_u8() {
+        Some(c) => {
+          buf[cnt] = c;
+          cnt += 1;
+        },
+        None => {
+          break;
+        }
+      }
+    }
+
+    Ok(cnt)
   }
 }
 
@@ -253,7 +353,7 @@ where
       // Special handling before we send the character
       match byte {
         b'\n' => {
-          if self.tx_options.lf_to_crlf() {
+          if self.serial_options.lf_to_crlf() {
             self.port.write_u8(b'\r');
           }
         },
@@ -266,15 +366,15 @@ where
       // Special handling after we send the character
       match byte {
         b'\r' => {
-          if self.tx_options.cr_to_crlf() {
+          if self.serial_options.cr_to_crlf() {
             self.port.write_u8(b'\n');
           }
-          if self.tx_options.flush_on_eol() {
+          if self.serial_options.flush_on_eol() {
             self.port.flush();
           }
         },
         b'\n' => {
-          if self.tx_options.flush_on_eol() {
+          if self.serial_options.flush_on_eol() {
             self.port.flush();
           }
         },
@@ -290,15 +390,60 @@ where
   }
 }
 
-impl<P,T,R,S> core::fmt::Write for SerialPort<'_,P,T,R,S>
+impl<P,T,R,S> ufmt_write::uWrite for SerialPort<'_,P,T,R,S>
+  where
+    P: 'static + SerialRxTx,
+    T: 'static + Pin,
+    R: 'static + Pin,
+    S: EventSink
+{
+  type Error = core::convert::Infallible;
+
+  fn write_str(&mut self, s: &str) -> Result<(), Self::Error> {
+    let _ignore = crate::io::Write::write(self, s.as_bytes());
+    Ok(())
+  }
+}
+
+impl<P,T,R,S> crate::io::Write for Handle<SerialPort<'_,P,T,R,S>>
 where
   P: 'static + SerialRxTx,
   T: 'static + Pin,
   R: 'static + Pin,
   S: EventSink
 {
-  fn write_str(&mut self, s: &str) -> core::fmt::Result {
-    let _ignore = crate::io::Write::write(self, s.as_bytes());
-    Ok(())
+  fn write(&mut self, buf: &[u8]) -> crate::io::Result<usize> {
+    Handle::deref_mut(self).write(buf)
+  }
+
+  fn flush(&mut self) -> crate::io::Result<()> {
+    Handle::deref_mut(self).flush()
   }
 }
+
+impl<P,T,R,S> crate::io::Read for Handle<SerialPort<'_,P,T,R,S>>
+where
+  P: 'static + SerialRxTx,
+  T: 'static + Pin,
+  R: 'static + Pin,
+  S: EventSink
+{
+  fn read(&mut self, buf: &mut [u8]) -> crate::io::Result<usize> {
+    Handle::deref_mut(self).read(buf)
+  }
+}
+
+impl<P,T,R,S> ufmt_write::uWrite for Handle<SerialPort<'_,P,T,R,S>>
+  where
+    P: 'static + SerialRxTx,
+    T: 'static + Pin,
+    R: 'static + Pin,
+    S: EventSink
+{
+  type Error = core::convert::Infallible;
+
+  fn write_str(&mut self, s: &str) -> Result<(), Self::Error> {
+    Handle::deref_mut(self).write_str(s)
+  }
+}
+
