@@ -3,7 +3,30 @@
  * Developed by Tim Walls <tim.walls@snowgoons.com>
  * Copyright (c) All Rights Reserved, Tim Walls
  */
-
+//! Provides a single point of access to the hardware devices associated with
+//! the AVR CPU on which we are running.
+//!
+//! This struct is your first port of call for accessing a pin, timer, or
+//! any other hardware component which we have support for.
+//!
+//! It is implemented as a global singleton, a reference is obtained using
+//! the provided instance() function.  From here, you can then obtain
+//! references to all the supported low-level hardware devices.
+//!
+//! # Example usage
+//! ```rust
+//! use avr_oxide::hal::atmega4809;
+//!
+//! fn use_hardware() {
+//!   let hardware = atmega4809::hardware::instance();
+//!
+//!   // Get a reference to the EEPROM device
+//!   let eeprom = &hardware.eeprom;
+//!
+//!   // Get a reference to Port D
+//!   let portd = &hardware.portd;
+//! }
+//! ```
 
 // Imports ===================================================================
 use crate::hal::atmega4809;
@@ -33,6 +56,9 @@ pub struct Hardware {
 
   pub watchdog: &'static mut atmega4809::watchdog::WatchdogImpl,
 
+  pub eeprom: &'static mut atmega4809::eeprom::eeprom::EepromImpl,
+  pub userrow: &'static mut atmega4809::eeprom::userrow::EepromImpl,
+
   #[cfg(feature="usart0")]
   pub usart0: &'static mut atmega4809::serial::usart0::SerialImpl,
   #[cfg(feature="usart1")]
@@ -59,6 +85,8 @@ mut_singleton!(Hardware, HARDWARE, instance,
     #[cfg(feature="rtc")]
     rtc: atmega4809::timer::rtc::instance(),
 
+    eeprom: atmega4809::eeprom::eeprom::instance(),
+    userrow: atmega4809::eeprom::userrow::instance(),
 
     porta: atmega4809::port::porta::instance(),
     portb: atmega4809::port::portb::instance(),
