@@ -15,11 +15,7 @@ pub mod hardware;
 pub mod debugled;
 pub mod watchdog;
 pub mod serial;
-
-#[cfg(any(feature="stdout_usart0",feature="stdout_usart1",feature="stdout_usart2",feature="stdout_usart3"))]
-use crate::stdout;
-
-
+pub mod eeprom;
 
 
 #[cfg(feature="panic_handler")]
@@ -30,35 +26,23 @@ fn panic(info: &core::panic::PanicInfo) -> ! {
   unsafe {
     crate::hal::concurrency::interrupt::disable_interrupts();
 
-    #[cfg(feature="stdout")]
+    #[cfg(feature="panicout")]
     {
-      let serial = stdout!();
-
-      // Remember, at the moment we can't do division involving 32 bit
-      // numbers, because of Rust/LLVM/AVR bugs 🙄🙄🙄
-      // @todo rework this so I can print 32 bit numbers without using 32bit
-      //       maths.
-      fn print_u16(val: u16) {
-        if val > 9 {
-          print_u16(val/10);
-        }
-        stdout!().blocking_write_u8(((val % 10) + 0x30) as u8);
-      }
-
+      use crate::util::{debug_print, debug_print_u16};
       // This doesn't look too pretty, but we can't use any of the standard
       // formatting routines because they require an allocator, which even
       // if we have one, is probably broken right now.
       // Plus the standard formatter routines don't know that we can't use
       // 32 bit arithmetic at the moment 😖
-      serial.blocking_write_slice(b"\n\nPanic:\n");
+      debug_print("\n\nPanic:\n");
       if let Some(location) = info.location() {
-        serial.blocking_write_slice(b"   --> ");
-        serial.blocking_write_slice(location.file().as_bytes());
-        serial.blocking_write_u8(b':');
-        print_u16(location.line() as u16);
-        serial.blocking_write_u8(b':');
-        print_u16(location.column() as u16);
-        serial.blocking_write_u8(b'\n');
+        debug_print("   --> ");
+        debug_print(&location.file());
+        debug_print(":");
+        debug_print_u16(location.line() as u16);
+        debug_print(":");
+        debug_print_u16(location.column() as u16);
+        debug_print("\n");
       }
     }
 
@@ -92,4 +76,11 @@ const ADDR_TCB1:    u16 = 0x0A90;
 const ADDR_TCB2:    u16 = 0x0AA0;
 const ADDR_TCB3:    u16 = 0x0AB0;
 const ADDR_WDT:     u16 = 0x0100;
-const ADDR_RTC:     u16 = 0x0140;
\ No newline at end of file
+const ADDR_RTC:     u16 = 0x0140;
+const ADDR_NVMCTRL: u16 = 0x1000;
+const ADDR_USERROW_PBUF: u16 = 0x1300;
+const ADDR_EEPROM_PBUF:  u16 = 0x1400;
+const EEPROM_PAGESIZE : usize = 64;
+const EEPROM_PAGES    : usize = 4;
+const USERROW_PAGESIZE: usize = 64;
+const USERROW_PAGES   : usize = 1;
\ No newline at end of file
