@@ -11,22 +11,30 @@
 // Declarations ==============================================================
 
 
-pub mod stdout {
-  #[cfg(feature="stdout_usart0")]
+#[cfg(feature="panicout_usart0")]
+pub mod panicout {
+  #[doc(hidden)]
   #[macro_export]
-  macro_rules! stdout { () => { crate::hal::atmega4809::serial::usart0::instance() }}
+  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart0::instance() }}
+}
 
-  #[cfg(feature="stdout_usart1")]
+#[cfg(feature="panicout_usart1")]
+pub mod panicout {
+  #[doc(hidden)]
   #[macro_export]
-  macro_rules! stdout { () => { crate::hal::atmega4809::serial::usart1::instance() }}
-
-  #[cfg(feature="stdout_usart2")]
+  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart1::instance() }}
+}
+#[cfg(feature="panicout_usart2")]
+pub mod panicout {
+  #[doc(hidden)]
   #[macro_export]
-  macro_rules! stdout { () => { crate::hal::atmega4809::serial::usart2::instance() }}
-
-  #[cfg(feature="stdout_usart3")]
+  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart2::instance() }}
+}
+#[cfg(feature="panicout_usart3")]
+pub mod panicout {
+  #[doc(hidden)]
   #[macro_export]
-  macro_rules! stdout { () => { crate::hal::atmega4809::serial::usart3::instance() }}
+  macro_rules! panic_stdout { () => { crate::hal::atmega4809::serial::usart3::instance() }}
 }
 
 // Code ======================================================================
