@@ -36,6 +36,12 @@ pub mod tcb3 {
 
   atmel_tcb!(super::super::ADDR_TCB3, crate::hal::generic::timer::TimerIdentity::Tcb3, _ivr_tcb3_int);
 }
+#[cfg(feature="rtc")]
+pub mod rtc {
+  use crate::atmel_rtc;
+
+  atmel_rtc!(super::super::ADDR_RTC, crate::hal::generic::timer::TimerIdentity::Rtc, _ivr_rtc_pit);
+}
 
 
 // Tests =====================================================================
