@@ -194,9 +194,6 @@ pub mod interrupt {
       #[cfg(target_arch="avr")]
       let sreg = crate::cpu!().read_sreg();
 
-      #[cfg(not(target_arch="avr"))]
-      println!("In isolated block");
-
       disable_interrupts();
 
       let result = f();
@@ -205,9 +202,6 @@ pub mod interrupt {
       #[cfg(target_arch="avr")]
       crate::cpu!().write_sreg(sreg);
 
-      #[cfg(not(target_arch="avr"))]
-      println!("Leaving isolated block");
-
       result
     }
   }
@@ -239,12 +233,14 @@ pub mod interrupt {
   #[cfg(target_arch="avr")]
   #[inline(always)]
   pub(crate) unsafe fn enable_interrupts(){
+    #![allow(deprecated)] // until asm! is implemented for AVR
     llvm_asm!("sei" :::: "volatile")
   }
 
   #[cfg(target_arch="avr")]
   #[inline(always)]
   pub(crate) unsafe fn disable_interrupts() {
+    #![allow(deprecated)] // until asm! is implemented for AVR
     llvm_asm!("cli" :::: "volatile")
   }
 
@@ -257,6 +253,7 @@ pub mod interrupt {
   #[inline(always)]
   pub fn wait() {
     unsafe {
+      #![allow(deprecated)] // until asm! is implemented for AVR
       llvm_asm!("sleep");
     }
   }
