@@ -12,6 +12,7 @@ pub mod debugled;
 pub mod watchdog;
 pub mod cpu;
 pub mod serial;
+pub mod eeprom;
 
 
 #[allow(unused_assignments)]
@@ -48,12 +49,18 @@ pub(in crate) fn busy_loop(c: u16) {
 pub unsafe extern "C" fn rust_eh_personality() {
 }
 
+/**
+ * Volatile write to a variable by reference
+ */
 #[macro_export]
 macro_rules! v_write {
   ($type:ty, $ref:expr, $val:expr) => {
     core::ptr::write_volatile(&mut $ref as *mut $type, $val)
   }
 }
+/**
+ * Volatile read from a variable by reference
+ */
 #[macro_export]
 macro_rules! v_read {
   ($type:ty, $ref:expr) => {
