@@ -10,13 +10,15 @@
 
 
 use core::any::Any;
+use ufmt::derive::uDebug;
+use oxide_macros::Persist;
 use crate::hal::generic::callback::IsrCallback;
 
 // Declarations ==============================================================
 /**
  * Input/output mode for a pin
  */
-#[derive(Clone,Copy,PartialEq,Eq)]
+#[derive(Clone,Copy,PartialEq,Eq,uDebug,Persist)]
 pub enum PinMode {
   /// Pin is configured as output
   Output,
@@ -29,7 +31,7 @@ pub enum PinMode {
 /**
  * Interrupt generation mode for a pin
  */
-#[derive(Clone,Copy,PartialEq,Eq)]
+#[derive(Clone,Copy,PartialEq,Eq,uDebug,Persist)]
 pub enum InterruptMode {
   /// Do not generate interrupts
   Disabled,
@@ -46,7 +48,7 @@ pub enum InterruptMode {
 /**
  * Identifies a particular pin as the source of an event at runtime.
  */
-#[derive(Clone,Copy,PartialEq,Eq)]
+#[derive(Clone,Copy,PartialEq,Eq,uDebug,Persist)]
 pub enum PinIdentity {
   /// Port A, pin number (u8)
   PortA(u8),
@@ -270,6 +272,7 @@ pub mod base {
     }
   }
 
+  #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_port_tpl {
     ($ref:expr, $portsrc:expr, $isr:ident) => {
@@ -525,6 +528,7 @@ pub mod base {
 
   }
 
+  #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_port_tpl {
     ($ref:expr, $portsrc:expr, $isr:ident) => {
