@@ -7,6 +7,8 @@
 
 // Imports ===================================================================
 use core::any::Any;
+use ufmt::derive::uDebug;
+use oxide_macros::Persist;
 use crate::hal::generic::callback::IsrCallback;
 
 // Declarations ==============================================================
@@ -20,7 +22,7 @@ pub enum TimerMode {
  * Identifies a particular source of timer events, i.e. a particular hardware
  * clock source, at runtime.
  */
-#[derive(Clone,Copy,PartialEq,Eq)]
+#[derive(Clone,Copy,PartialEq,Eq,uDebug,Persist)]
 pub enum TimerIdentity {
   /// Timer-Counter Type B, 0
   Tcb0,
@@ -311,6 +313,7 @@ pub mod base {
     }
   }
 
+  #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_tcb {
     ($tcbref:expr, $timersrc:expr, $isr:ident) => {
@@ -576,6 +579,7 @@ pub mod base {
     }
   }
 
+  #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_rtc {
     ($rtcref:expr, $timersrc:expr, $isr: ident) => {
@@ -729,6 +733,7 @@ pub mod base {
     }
   }
 
+  #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_tcb {
     ($tcbref:expr, $timersrc:expr, $isr:ident) => {
@@ -848,8 +853,7 @@ pub mod base {
     }
   }
 
-
-
+  #[doc(hidden)]
   #[macro_export]
   macro_rules! atmel_rtc {
     ($rtcref:expr, $timersrc:expr, $isr: ident) => {
